<xsl:stylesheet
    version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns="http://www.w3.org/TR/xhtml1/strict">

    <xsl:output method="html"/>
    <xsl:include href="page.xsl"/>

    <xsl:template match="/">
	<xsl:apply-templates/>
    </xsl:template>

    <xsl:template match="p">
        <p>
	    <xsl:apply-templates/>
	</p>
    </xsl:template>

    <xsl:template match="list">
	<ul>
	    <xsl:for-each select="item">
		<li>
		    <xsl:apply-templates/>
		</li>
	    </xsl:for-each>
	</ul>
    </xsl:template>

    <xsl:template match="a">
	<a href="{@href}" name="{@id}">
	    <xsl:apply-templates/>
	</a>
    </xsl:template>

    <xsl:template match="img">
	<img src="{@src}" alt="{@alt}"/>
    </xsl:template>


    <xsl:template match="code">
	<pre class="ccode">
	    <xsl:apply-templates/>
	</pre>
    </xsl:template>

    <xsl:template match="section">
	<xsl:variable name="level"><xsl:value-of select="count(ancestor::section)"/></xsl:variable>
	<xsl:element name="h{$level+2}">
	    <xsl:attribute name="id"><xsl:value-of select="@title"/></xsl:attribute>
	    <xsl:attribute name="class">section</xsl:attribute>
	    <xsl:value-of select="@title"/>
	</xsl:element>
	<xsl:apply-templates/>
    </xsl:template>

    <!-- Note that this template may generate incorrect link values if section
	 titles are not unique -->
    <xsl:template match="contents">
	<xsl:variable name="levelindent">10</xsl:variable>
	<p style="font-weight:bold;">Contents</p>
	<xsl:for-each select="//section">
	    <xsl:element name="p">
		<xsl:variable name="level"><xsl:value-of select="count(ancestor::section)"/></xsl:variable>
		<xsl:attribute name="style">padding-left:<xsl:value-of select="$level*$levelindent"/>mm;</xsl:attribute>
		<xsl:element name="a">
		    <xsl:attribute name="href">#<xsl:value-of select="@title"/></xsl:attribute>
		    <xsl:apply-templates select="@title"/>
		</xsl:element>
	    </xsl:element>
	</xsl:for-each>
    </xsl:template>

    <xsl:template match="content-list">
	<p>
	    <span style="font-weight:bold;">Contents:</span>
	    <xsl:for-each select="//section">
		<xsl:element name="a">
		    <xsl:attribute name="class">content-list</xsl:attribute>
		    <xsl:attribute name="href">#`</xsl:attribute>
		    <xsl:apply-templates select="@title"/>
		</xsl:element>
	    </xsl:for-each>
	</p>
    </xsl:template>

    <xsl:template match="message">
	<p>
	    <xsl:apply-templates/>
	</p>
	<p class="messagestamp">
	    <xsl:value-of select="@date"/> by <xsl:value-of select="@author"/>
	</p>
	<hr/>
    </xsl:template>
    
    <xsl:template match="license">
	<pre class="license">
	    <xsl:apply-templates/>	    
	</pre>
    </xsl:template>

    <xsl:template match="author-sign">
	<hr/>
	<p class="author-sign">
	    (C) <xsl:value-of select="@name"/>, <xsl:value-of select="@date"/>
	</p>
    </xsl:template>

</xsl:stylesheet>
												      
